Headers

Struct Headers 

pub struct Headers(/* private fields */);
A collection of headers stored in super::CommitData.

Note: these do not include tree, parent, author, and committer.

Implementations

Source

impl Headers

pub fn new() -> Self

pub fn iter(&self) -> impl Iterator<Item = (&str, &str)>

pub fn values<'a>(&'a self, name: &'a str) -> impl Iterator<Item = &'a str> + 'a

pub fn signatures(&self) -> impl Iterator<Item = Signature<'_>> + '_

pub fn push(&mut self, name: &str, value: &str)

Push a header to the end of the headers section.