pub struct OwnedTrailer {
pub token: OwnedToken,
pub value: String,
}Expand description
A version of the Trailer which owns its token and
value. Useful for when you need to carry trailers around in a long
lived data structure.
Fields
token: OwnedTokenvalue: StringTrait Implementations
Sourceimpl Clone for OwnedTrailer
impl Clone for OwnedTrailer
Sourcefn clone(&self) -> OwnedTrailer
fn clone(&self) -> OwnedTrailer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnedTrailer
impl Debug for OwnedTrailer
Sourceimpl<'a> From<&'a OwnedTrailer> for Trailer<'a>
impl<'a> From<&'a OwnedTrailer> for Trailer<'a>
Sourcefn from(t: &'a OwnedTrailer) -> Self
fn from(t: &'a OwnedTrailer) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<&Trailer<'a>> for OwnedTrailer
impl<'a> From<&Trailer<'a>> for OwnedTrailer
Sourceimpl<'a> From<Trailer<'a>> for OwnedTrailer
impl<'a> From<Trailer<'a>> for OwnedTrailer
Sourceimpl Hash for OwnedTrailer
impl Hash for OwnedTrailer
Sourceimpl Ord for OwnedTrailer
impl Ord for OwnedTrailer
Sourcefn cmp(&self, other: &OwnedTrailer) -> Ordering
fn cmp(&self, other: &OwnedTrailer) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OwnedTrailer
impl PartialEq for OwnedTrailer
Sourceimpl PartialOrd for OwnedTrailer
impl PartialOrd for OwnedTrailer
impl Eq for OwnedTrailer
impl StructuralPartialEq for OwnedTrailer